database library

Classes

$$AlbumTableAnnotationComposer
$$AlbumTableFilterComposer
$$AlbumTableOrderingComposer
$$AlbumTableReferences
$$AlbumTableTableManager
$$AppUserTableAnnotationComposer
$$AppUserTableFilterComposer
$$AppUserTableOrderingComposer
$$AppUserTableReferences
$$AppUserTableTableManager
$$BookTableAnnotationComposer
$$BookTableFilterComposer
$$BookTableOrderingComposer
$$BookTableReferences
$$BookTableTableManager
$$CategoryTableAnnotationComposer
$$CategoryTableFilterComposer
$$CategoryTableOrderingComposer
$$CategoryTableReferences
$$CategoryTableTableManager
$$CompanyTableAnnotationComposer
$$CompanyTableFilterComposer
$$CompanyTableOrderingComposer
$$CompanyTableReferences
$$CompanyTableTableManager
$$ContributorTableAnnotationComposer
$$ContributorTableFilterComposer
$$ContributorTableOrderingComposer
$$ContributorTableReferences
$$ContributorTableTableManager
$$CountryTableAnnotationComposer
$$CountryTableFilterComposer
$$CountryTableOrderingComposer
$$CountryTableReferences
$$CountryTableTableManager
$$CouponTableAnnotationComposer
$$CouponTableFilterComposer
$$CouponTableOrderingComposer
$$CouponTableReferences
$$CouponTableTableManager
$$CouponTypeTableAnnotationComposer
$$CouponTypeTableFilterComposer
$$CouponTypeTableOrderingComposer
$$CouponTypeTableReferences
$$CouponTypeTableTableManager
$$CurrencyTableAnnotationComposer
$$CurrencyTableFilterComposer
$$CurrencyTableOrderingComposer
$$CurrencyTableTableManager
$$CustomerTableAnnotationComposer
$$CustomerTableFilterComposer
$$CustomerTableOrderingComposer
$$CustomerTableReferences
$$CustomerTableTableManager
$$DepartmentTableAnnotationComposer
$$DepartmentTableFilterComposer
$$DepartmentTableOrderingComposer
$$DepartmentTableReferences
$$DepartmentTableTableManager
$$EmployeePositionTableAnnotationComposer
$$EmployeePositionTableFilterComposer
$$EmployeePositionTableOrderingComposer
$$EmployeePositionTableReferences
$$EmployeePositionTableTableManager
$$EmployeeTableAnnotationComposer
$$EmployeeTableFilterComposer
$$EmployeeTableOrderingComposer
$$EmployeeTableReferences
$$EmployeeTableTableManager
$$EmploymentHistoryTableAnnotationComposer
$$EmploymentHistoryTableFilterComposer
$$EmploymentHistoryTableOrderingComposer
$$EmploymentHistoryTableReferences
$$EmploymentHistoryTableTableManager
$$FootballPlayerTableAnnotationComposer
$$FootballPlayerTableFilterComposer
$$FootballPlayerTableOrderingComposer
$$FootballPlayerTableReferences
$$FootballPlayerTableTableManager
$$GenderTableAnnotationComposer
$$GenderTableFilterComposer
$$GenderTableOrderingComposer
$$GenderTableReferences
$$GenderTableTableManager
$$LanguageTableAnnotationComposer
$$LanguageTableFilterComposer
$$LanguageTableOrderingComposer
$$LanguageTableTableManager
$$LessonTableAnnotationComposer
$$LessonTableFilterComposer
$$LessonTableOrderingComposer
$$LessonTableReferences
$$LessonTableTableManager
$$NoteTableAnnotationComposer
$$NoteTableFilterComposer
$$NoteTableOrderingComposer
$$NoteTableTableManager
$$NotificationMessageTableAnnotationComposer
$$NotificationMessageTableFilterComposer
$$NotificationMessageTableOrderingComposer
$$NotificationMessageTableTableManager
$$PaymentGatewayTableAnnotationComposer
$$PaymentGatewayTableFilterComposer
$$PaymentGatewayTableOrderingComposer
$$PaymentGatewayTableTableManager
$$ProductTableAnnotationComposer
$$ProductTableFilterComposer
$$ProductTableOrderingComposer
$$ProductTableReferences
$$ProductTableTableManager
$$ProjectTableAnnotationComposer
$$ProjectTableFilterComposer
$$ProjectTableOrderingComposer
$$ProjectTableReferences
$$ProjectTableTableManager
$$SalesOrderLineTableAnnotationComposer
$$SalesOrderLineTableFilterComposer
$$SalesOrderLineTableOrderingComposer
$$SalesOrderLineTableReferences
$$SalesOrderLineTableTableManager
$$SalesOrderTableAnnotationComposer
$$SalesOrderTableFilterComposer
$$SalesOrderTableOrderingComposer
$$SalesOrderTableReferences
$$SalesOrderTableTableManager
$$SongTableAnnotationComposer
$$SongTableFilterComposer
$$SongTableOrderingComposer
$$SongTableReferences
$$SongTableTableManager
$$SupplierTableAnnotationComposer
$$SupplierTableFilterComposer
$$SupplierTableOrderingComposer
$$SupplierTableReferences
$$SupplierTableTableManager
$$SupplierTypeTableAnnotationComposer
$$SupplierTypeTableFilterComposer
$$SupplierTypeTableOrderingComposer
$$SupplierTypeTableReferences
$$SupplierTypeTableTableManager
$$SystemLogTableAnnotationComposer
$$SystemLogTableFilterComposer
$$SystemLogTableOrderingComposer
$$SystemLogTableTableManager
$$TeacherPositionTableAnnotationComposer
$$TeacherPositionTableFilterComposer
$$TeacherPositionTableOrderingComposer
$$TeacherPositionTableReferences
$$TeacherPositionTableTableManager
$$TeacherTableAnnotationComposer
$$TeacherTableFilterComposer
$$TeacherTableOrderingComposer
$$TeacherTableReferences
$$TeacherTableTableManager
$$UniversityTableAnnotationComposer
$$UniversityTableFilterComposer
$$UniversityTableOrderingComposer
$$UniversityTableReferences
$$UniversityTableTableManager
$AlbumTable
$AppUserTable
$BookTable
$CategoryTable
$CompanyTable
$ContributorTable
$CountryTable
$CouponTable
$CouponTypeTable
$CurrencyTable
$CustomerTable
$DepartmentTable
$EmployeePositionTable
$EmployeeTable
$EmploymentHistoryTable
$FootballPlayerTable
$GenderTable
$LanguageTable
$LessonTable
$NoteTable
$NotificationMessageTable
$PaymentGatewayTable
$ProductTable
$ProjectTable
$SalesOrderLineTable
$SalesOrderTable
$SharedDatabaseManager
$SongTable
$SupplierTable
$SupplierTypeTable
$SystemLogTable
$TeacherPositionTable
$TeacherTable
$UniversityTable
Album
AlbumCompanion
AlbumDAO
AlbumDAOManager
AlbumData
AppUser
AppUserCompanion
AppUserDAO
AppUserDAOManager
AppUserData
BestSellingDAO
BestSellingDAOManager
Book
BookCompanion
BookDAO
BookDAOManager
BookData
Category
CategoryCompanion
CategoryDAO
CategoryDAOManager
CategoryData
Company
CompanyCompanion
CompanyDAO
CompanyDAOManager
CompanyData
Contributor
ContributorCompanion
ContributorDAO
ContributorDAOManager
ContributorData
Country
CountryCompanion
CountryDAO
CountryDAOManager
CountryData
Coupon
CouponCompanion
CouponDAO
CouponDAOManager
CouponData
CouponType
CouponTypeCompanion
CouponTypeDAO
CouponTypeDAOManager
CouponTypeData
Currency
CurrencyCompanion
CurrencyDAO
CurrencyDAOManager
CurrencyData
Customer
CustomerCompanion
CustomerDAO
CustomerDAOManager
CustomerData
Department
DepartmentCompanion
DepartmentDAO
DepartmentDAOManager
DepartmentData
Employee
EmployeeCompanion
EmployeeDAO
EmployeeDAOManager
EmployeeData
EmployeePosition
EmployeePositionCompanion
EmployeePositionDAO
EmployeePositionDAOManager
EmployeePositionData
EmploymentHistory
EmploymentHistoryCompanion
EmploymentHistoryDAO
EmploymentHistoryDAOManager
EmploymentHistoryData
FootballPlayer
FootballPlayerCompanion
FootballPlayerDAO
FootballPlayerDAOManager
FootballPlayerData
Gender
GenderCompanion
GenderDAO
GenderDAOManager
GenderData
Language
LanguageCompanion
LanguageDAO
LanguageDAOManager
LanguageData
Lesson
LessonCompanion
LessonDAO
LessonDAOManager
LessonData
Note
NoteCompanion
NoteDAO
NoteDAOManager
NoteData
NotificationMessage
NotificationMessageCompanion
NotificationMessageDAO
NotificationMessageDAOManager
NotificationMessageData
PaymentGateway
PaymentGatewayCompanion
PaymentGatewayDAO
PaymentGatewayDAOManager
PaymentGatewayData
Product
ProductCompanion
ProductDAO
ProductDAOManager
ProductData
Project
ProjectCompanion
ProjectDAO
ProjectDAOManager
ProjectData
SalesOrder
SalesOrderCompanion
SalesOrderDAO
SalesOrderDAOManager
SalesOrderData
SalesOrderLine
SalesOrderLineCompanion
SalesOrderLineDAO
SalesOrderLineDAOManager
SalesOrderLineData
SharedDatabase
Song
SongCompanion
SongDAO
SongDAOManager
SongData
Supplier
SupplierCompanion
SupplierDAO
SupplierDAOManager
SupplierData
SupplierType
SupplierTypeCompanion
SupplierTypeDAO
SupplierTypeDAOManager
SupplierTypeData
SystemLog
SystemLogCompanion
SystemLogDAO
SystemLogDAOManager
SystemLogData
Teacher
TeacherCompanion
TeacherDAO
TeacherDAOManager
TeacherData
TeacherPosition
TeacherPositionCompanion
TeacherPositionDAO
TeacherPositionDAOManager
TeacherPositionData
University
UniversityCompanion
UniversityDAO
UniversityDAOManager
UniversityData

Functions

getSharedDatabase() → Future<SharedDatabase>
initAlbums(SharedDatabase database) → Future<void>
initAppUsers(SharedDatabase database) → Future<void>
initBooks(SharedDatabase database) → Future<void>
initCategories(SharedDatabase database) → Future<void>
initCompanies(SharedDatabase database) → Future<void>
initContributors(SharedDatabase database) → Future<void>
initCountries(SharedDatabase database) → Future<void>
initCoupons(SharedDatabase database) → Future<void>
initCouponTypes(SharedDatabase database) → Future<void>
initCurrencies(SharedDatabase database) → Future<void>
initCustomers(SharedDatabase database) → Future<void>
initDepartments(SharedDatabase database) → Future<void>
initEmployeePositions(SharedDatabase database) → Future<void>
initEmployees(SharedDatabase database) → Future<void>
initEmploymentHistories(SharedDatabase database) → Future<void>
initFootballPlayers(SharedDatabase database) → Future<void>
initGenders(SharedDatabase database) → Future<void>
initLanguages(SharedDatabase database) → Future<void>
initLessons(SharedDatabase database) → Future<void>
initNotes(SharedDatabase database) → Future<void>
initProducts(SharedDatabase database) → Future<void>
initProjects(SharedDatabase database) → Future<void>
initSaleOrders(SharedDatabase database) → Future<void>
initSongs(SharedDatabase database) → Future<void>
initSuppliers(SharedDatabase database) → Future<void>
initSupplierTypes(SharedDatabase database) → Future<void>
initSystemLogs(SharedDatabase database) → Future<void>
initTeacherPositions(SharedDatabase database) → Future<void>
initTeachers(SharedDatabase database) → Future<void>
initUniversities(SharedDatabase database) → Future<void>

Typedefs

$$AlbumTableCreateCompanionBuilder = AlbumCompanion Function({required String code, Value<String?> description, Value<int> id, Value<String?> imagePath, required bool locked, required String name, required String nameInEnglish, Value<String?> note, required bool published, required int publishedSongCount, required int seqNum, required int totalSongCount})
$$AlbumTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $AlbumTable, AlbumData, $$AlbumTableFilterComposer, $$AlbumTableOrderingComposer, $$AlbumTableAnnotationComposer, $$AlbumTableCreateCompanionBuilder, $$AlbumTableUpdateCompanionBuilder, (AlbumData, $$AlbumTableReferences), AlbumData, PrefetchHooks Function({bool songRefs})>
$$AlbumTableUpdateCompanionBuilder = AlbumCompanion Function({Value<String> code, Value<String?> description, Value<int> id, Value<String?> imagePath, Value<bool> locked, Value<String> name, Value<String> nameInEnglish, Value<String?> note, Value<bool> published, Value<int> publishedSongCount, Value<int> seqNum, Value<int> totalSongCount})
$$AppUserTableCreateCompanionBuilder = AppUserCompanion Function({Value<String?> accessToken, required bool activated, required String email, Value<int?> employeeId, required bool enabled, required String encryptedPassword, required String fullName, Value<int> id, Value<String?> imagePath, required bool isSystemUser, Value<DateTime?> lastActiveDatetime, required String userName})
$$AppUserTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $AppUserTable, AppUserData, $$AppUserTableFilterComposer, $$AppUserTableOrderingComposer, $$AppUserTableAnnotationComposer, $$AppUserTableCreateCompanionBuilder, $$AppUserTableUpdateCompanionBuilder, (AppUserData, $$AppUserTableReferences), AppUserData, PrefetchHooks Function({bool contributorRefs, bool employeeId})>
$$AppUserTableUpdateCompanionBuilder = AppUserCompanion Function({Value<String?> accessToken, Value<bool> activated, Value<String> email, Value<int?> employeeId, Value<bool> enabled, Value<String> encryptedPassword, Value<String> fullName, Value<int> id, Value<String?> imagePath, Value<bool> isSystemUser, Value<DateTime?> lastActiveDatetime, Value<String> userName})
$$BookTableCreateCompanionBuilder = BookCompanion Function({required String code, Value<String?> description, Value<int> id, Value<String?> imagePath, required bool locked, Value<String?> note, required bool published, required int seqNum, required String title})
$$BookTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $BookTable, BookData, $$BookTableFilterComposer, $$BookTableOrderingComposer, $$BookTableAnnotationComposer, $$BookTableCreateCompanionBuilder, $$BookTableUpdateCompanionBuilder, (BookData, $$BookTableReferences), BookData, PrefetchHooks Function({bool lessonRefs})>
$$BookTableUpdateCompanionBuilder = BookCompanion Function({Value<String> code, Value<String?> description, Value<int> id, Value<String?> imagePath, Value<bool> locked, Value<String?> note, Value<bool> published, Value<int> seqNum, Value<String> title})
$$CategoryTableCreateCompanionBuilder = CategoryCompanion Function({required String code, Value<String?> description, Value<int> id, Value<String?> imagePath, required String name})
$$CategoryTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $CategoryTable, CategoryData, $$CategoryTableFilterComposer, $$CategoryTableOrderingComposer, $$CategoryTableAnnotationComposer, $$CategoryTableCreateCompanionBuilder, $$CategoryTableUpdateCompanionBuilder, (CategoryData, $$CategoryTableReferences), CategoryData, PrefetchHooks Function({bool productRefs})>
$$CategoryTableUpdateCompanionBuilder = CategoryCompanion Function({Value<String> code, Value<String?> description, Value<int> id, Value<String?> imagePath, Value<String> name})
$$CompanyTableCreateCompanionBuilder = CompanyCompanion Function({required String code, Value<int?> companyIdParent, Value<String?> description, Value<int> id, Value<String?> imagePath, required String name})
$$CompanyTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $CompanyTable, CompanyData, $$CompanyTableFilterComposer, $$CompanyTableOrderingComposer, $$CompanyTableAnnotationComposer, $$CompanyTableCreateCompanionBuilder, $$CompanyTableUpdateCompanionBuilder, (CompanyData, $$CompanyTableReferences), CompanyData, PrefetchHooks Function({bool companyIdParent, bool departmentRefs, bool employmentHistoryRefs})>
$$CompanyTableUpdateCompanionBuilder = CompanyCompanion Function({Value<String> code, Value<int?> companyIdParent, Value<String?> description, Value<int> id, Value<String?> imagePath, Value<String> name})
$$ContributorTableCreateCompanionBuilder = ContributorCompanion Function({required int appUserId, Value<int> id, required int projectId})
$$ContributorTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $ContributorTable, ContributorData, $$ContributorTableFilterComposer, $$ContributorTableOrderingComposer, $$ContributorTableAnnotationComposer, $$ContributorTableCreateCompanionBuilder, $$ContributorTableUpdateCompanionBuilder, (ContributorData, $$ContributorTableReferences), ContributorData, PrefetchHooks Function({bool appUserId, bool projectId})>
$$ContributorTableUpdateCompanionBuilder = ContributorCompanion Function({Value<int> appUserId, Value<int> id, Value<int> projectId})
$$CountryTableCreateCompanionBuilder = CountryCompanion Function({required int area, required String code, required String countryCode, Value<String?> description, Value<double?> gdp, required String id, required String isoCode2, required String isoCode3, required String name, required String nameInEnglish, required int population, Value<int> rowid})
$$CountryTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $CountryTable, CountryData, $$CountryTableFilterComposer, $$CountryTableOrderingComposer, $$CountryTableAnnotationComposer, $$CountryTableCreateCompanionBuilder, $$CountryTableUpdateCompanionBuilder, (CountryData, $$CountryTableReferences), CountryData, PrefetchHooks Function({bool footballPlayerRefs, bool teacherRefs})>
$$CountryTableUpdateCompanionBuilder = CountryCompanion Function({Value<int> area, Value<String> code, Value<String> countryCode, Value<String?> description, Value<double?> gdp, Value<String> id, Value<String> isoCode2, Value<String> isoCode3, Value<String> name, Value<String> nameInEnglish, Value<int> population, Value<int> rowid})
$$CouponTableCreateCompanionBuilder = CouponCompanion Function({required bool active, required String code, Value<String?> description, Value<int> id, required String name, required String type})
$$CouponTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $CouponTable, CouponData, $$CouponTableFilterComposer, $$CouponTableOrderingComposer, $$CouponTableAnnotationComposer, $$CouponTableCreateCompanionBuilder, $$CouponTableUpdateCompanionBuilder, (CouponData, $$CouponTableReferences), CouponData, PrefetchHooks Function({bool type})>
$$CouponTableUpdateCompanionBuilder = CouponCompanion Function({Value<bool> active, Value<String> code, Value<String?> description, Value<int> id, Value<String> name, Value<String> type})
$$CouponTypeTableCreateCompanionBuilder = CouponTypeCompanion Function({required String id, required String name, Value<int> rowid})
$$CouponTypeTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $CouponTypeTable, CouponTypeData, $$CouponTypeTableFilterComposer, $$CouponTypeTableOrderingComposer, $$CouponTypeTableAnnotationComposer, $$CouponTypeTableCreateCompanionBuilder, $$CouponTypeTableUpdateCompanionBuilder, (CouponTypeData, $$CouponTypeTableReferences), CouponTypeData, PrefetchHooks Function({bool couponRefs})>
$$CouponTypeTableUpdateCompanionBuilder = CouponTypeCompanion Function({Value<String> id, Value<String> name, Value<int> rowid})
$$CurrencyTableCreateCompanionBuilder = CurrencyCompanion Function({Value<String?> description, required String id, required String name, Value<int> rowid, required String symbol})
$$CurrencyTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $CurrencyTable, CurrencyData, $$CurrencyTableFilterComposer, $$CurrencyTableOrderingComposer, $$CurrencyTableAnnotationComposer, $$CurrencyTableCreateCompanionBuilder, $$CurrencyTableUpdateCompanionBuilder, (CurrencyData, BaseReferences<_$SharedDatabase, $CurrencyTable, CurrencyData>), CurrencyData, PrefetchHooks Function()>
$$CurrencyTableUpdateCompanionBuilder = CurrencyCompanion Function({Value<String?> description, Value<String> id, Value<String> name, Value<int> rowid, Value<String> symbol})
$$CustomerTableCreateCompanionBuilder = CustomerCompanion Function({Value<String?> address, required String code, required String email, Value<int> id, Value<String?> imagePath, required String name, Value<String?> phone, required bool vip})
$$CustomerTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $CustomerTable, CustomerData, $$CustomerTableFilterComposer, $$CustomerTableOrderingComposer, $$CustomerTableAnnotationComposer, $$CustomerTableCreateCompanionBuilder, $$CustomerTableUpdateCompanionBuilder, (CustomerData, $$CustomerTableReferences), CustomerData, PrefetchHooks Function({bool salesOrderRefs})>
$$CustomerTableUpdateCompanionBuilder = CustomerCompanion Function({Value<String?> address, Value<String> code, Value<String> email, Value<int> id, Value<String?> imagePath, Value<String> name, Value<String?> phone, Value<bool> vip})
$$DepartmentTableCreateCompanionBuilder = DepartmentCompanion Function({required String code, required int companyId, Value<String?> description, Value<int> id, Value<String?> imagePath, Value<int?> managerId, required String name})
$$DepartmentTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $DepartmentTable, DepartmentData, $$DepartmentTableFilterComposer, $$DepartmentTableOrderingComposer, $$DepartmentTableAnnotationComposer, $$DepartmentTableCreateCompanionBuilder, $$DepartmentTableUpdateCompanionBuilder, (DepartmentData, $$DepartmentTableReferences), DepartmentData, PrefetchHooks Function({bool companyId, bool employeeRefs, bool employmentHistoryRefs})>
$$DepartmentTableUpdateCompanionBuilder = DepartmentCompanion Function({Value<String> code, Value<int> companyId, Value<String?> description, Value<int> id, Value<String?> imagePath, Value<int?> managerId, Value<String> name})
$$EmployeePositionTableCreateCompanionBuilder = EmployeePositionCompanion Function({required String code, Value<int> id, required String name})
$$EmployeePositionTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $EmployeePositionTable, EmployeePositionData, $$EmployeePositionTableFilterComposer, $$EmployeePositionTableOrderingComposer, $$EmployeePositionTableAnnotationComposer, $$EmployeePositionTableCreateCompanionBuilder, $$EmployeePositionTableUpdateCompanionBuilder, (EmployeePositionData, $$EmployeePositionTableReferences), EmployeePositionData, PrefetchHooks Function({bool employeeRefs, bool employmentHistoryRefs})>
$$EmployeePositionTableUpdateCompanionBuilder = EmployeePositionCompanion Function({Value<String> code, Value<int> id, Value<String> name})
$$EmployeeTableCreateCompanionBuilder = EmployeeCompanion Function({Value<String?> address, required DateTime birthday, required int departmentId, required String email, required String empNumber, required int employeePositionId, required DateTime hireDate, Value<int> id, Value<String?> imagePath, required String name})
$$EmployeeTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $EmployeeTable, EmployeeData, $$EmployeeTableFilterComposer, $$EmployeeTableOrderingComposer, $$EmployeeTableAnnotationComposer, $$EmployeeTableCreateCompanionBuilder, $$EmployeeTableUpdateCompanionBuilder, (EmployeeData, $$EmployeeTableReferences), EmployeeData, PrefetchHooks Function({bool appUserRefs, bool departmentId, bool employeePositionId, bool employmentHistoryRefs, bool salesOrderRefs})>
$$EmployeeTableUpdateCompanionBuilder = EmployeeCompanion Function({Value<String?> address, Value<DateTime> birthday, Value<int> departmentId, Value<String> email, Value<String> empNumber, Value<int> employeePositionId, Value<DateTime> hireDate, Value<int> id, Value<String?> imagePath, Value<String> name})
$$EmploymentHistoryTableCreateCompanionBuilder = EmploymentHistoryCompanion Function({required int companyId, required int departmentId, required int employeeId, required int employeePositionId, required DateTime fromDate, Value<int> id, required DateTime toDate})
$$EmploymentHistoryTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $EmploymentHistoryTable, EmploymentHistoryData, $$EmploymentHistoryTableFilterComposer, $$EmploymentHistoryTableOrderingComposer, $$EmploymentHistoryTableAnnotationComposer, $$EmploymentHistoryTableCreateCompanionBuilder, $$EmploymentHistoryTableUpdateCompanionBuilder, (EmploymentHistoryData, $$EmploymentHistoryTableReferences), EmploymentHistoryData, PrefetchHooks Function({bool companyId, bool departmentId, bool employeeId, bool employeePositionId})>
$$EmploymentHistoryTableUpdateCompanionBuilder = EmploymentHistoryCompanion Function({Value<int> companyId, Value<int> departmentId, Value<int> employeeId, Value<int> employeePositionId, Value<DateTime> fromDate, Value<int> id, Value<DateTime> toDate})
$$FootballPlayerTableCreateCompanionBuilder = FootballPlayerCompanion Function({required DateTime birthday, required String countryId, Value<String?> description, required String fullName, Value<int> id, Value<String?> imagePath})
$$FootballPlayerTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $FootballPlayerTable, FootballPlayerData, $$FootballPlayerTableFilterComposer, $$FootballPlayerTableOrderingComposer, $$FootballPlayerTableAnnotationComposer, $$FootballPlayerTableCreateCompanionBuilder, $$FootballPlayerTableUpdateCompanionBuilder, (FootballPlayerData, $$FootballPlayerTableReferences), FootballPlayerData, PrefetchHooks Function({bool countryId})>
$$FootballPlayerTableUpdateCompanionBuilder = FootballPlayerCompanion Function({Value<DateTime> birthday, Value<String> countryId, Value<String?> description, Value<String> fullName, Value<int> id, Value<String?> imagePath})
$$GenderTableCreateCompanionBuilder = GenderCompanion Function({required String id, required String name, Value<int> rowid})
$$GenderTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $GenderTable, GenderData, $$GenderTableFilterComposer, $$GenderTableOrderingComposer, $$GenderTableAnnotationComposer, $$GenderTableCreateCompanionBuilder, $$GenderTableUpdateCompanionBuilder, (GenderData, $$GenderTableReferences), GenderData, PrefetchHooks Function({bool teacherRefs})>
$$GenderTableUpdateCompanionBuilder = GenderCompanion Function({Value<String> id, Value<String> name, Value<int> rowid})
$$LanguageTableCreateCompanionBuilder = LanguageCompanion Function({required String id, required String name, required String nameInEnglish, Value<int> rowid, required int seqNum})
$$LanguageTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $LanguageTable, LanguageData, $$LanguageTableFilterComposer, $$LanguageTableOrderingComposer, $$LanguageTableAnnotationComposer, $$LanguageTableCreateCompanionBuilder, $$LanguageTableUpdateCompanionBuilder, (LanguageData, BaseReferences<_$SharedDatabase, $LanguageTable, LanguageData>), LanguageData, PrefetchHooks Function()>
$$LanguageTableUpdateCompanionBuilder = LanguageCompanion Function({Value<String> id, Value<String> name, Value<String> nameInEnglish, Value<int> rowid, Value<int> seqNum})
$$LessonTableCreateCompanionBuilder = LessonCompanion Function({required int bookId, Value<String?> description, Value<int> id, Value<String?> imagePath, required bool locked, Value<String?> note, Value<DateTime?> publishDate, required bool published, required int seqNum, required String title, required String titleInEnglish})
$$LessonTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $LessonTable, LessonData, $$LessonTableFilterComposer, $$LessonTableOrderingComposer, $$LessonTableAnnotationComposer, $$LessonTableCreateCompanionBuilder, $$LessonTableUpdateCompanionBuilder, (LessonData, $$LessonTableReferences), LessonData, PrefetchHooks Function({bool bookId})>
$$LessonTableUpdateCompanionBuilder = LessonCompanion Function({Value<int> bookId, Value<String?> description, Value<int> id, Value<String?> imagePath, Value<bool> locked, Value<String?> note, Value<DateTime?> publishDate, Value<bool> published, Value<int> seqNum, Value<String> title, Value<String> titleInEnglish})
$$NoteTableCreateCompanionBuilder = NoteCompanion Function({required String colorCode, required String content, required DateTime createDateTime, Value<int> id, required String title})
$$NoteTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $NoteTable, NoteData, $$NoteTableFilterComposer, $$NoteTableOrderingComposer, $$NoteTableAnnotationComposer, $$NoteTableCreateCompanionBuilder, $$NoteTableUpdateCompanionBuilder, (NoteData, BaseReferences<_$SharedDatabase, $NoteTable, NoteData>), NoteData, PrefetchHooks Function()>
$$NoteTableUpdateCompanionBuilder = NoteCompanion Function({Value<String> colorCode, Value<String> content, Value<DateTime> createDateTime, Value<int> id, Value<String> title})
$$NotificationMessageTableCreateCompanionBuilder = NotificationMessageCompanion Function({required DateTime createDateTime, Value<int> id, required String message, required bool read, required String title, required String type})
$$NotificationMessageTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $NotificationMessageTable, NotificationMessageData, $$NotificationMessageTableFilterComposer, $$NotificationMessageTableOrderingComposer, $$NotificationMessageTableAnnotationComposer, $$NotificationMessageTableCreateCompanionBuilder, $$NotificationMessageTableUpdateCompanionBuilder, (NotificationMessageData, BaseReferences<_$SharedDatabase, $NotificationMessageTable, NotificationMessageData>), NotificationMessageData, PrefetchHooks Function()>
$$NotificationMessageTableUpdateCompanionBuilder = NotificationMessageCompanion Function({Value<DateTime> createDateTime, Value<int> id, Value<String> message, Value<bool> read, Value<String> title, Value<String> type})
$$PaymentGatewayTableCreateCompanionBuilder = PaymentGatewayCompanion Function({required bool active, required String id, required String name, Value<int> rowid})
$$PaymentGatewayTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $PaymentGatewayTable, PaymentGatewayData, $$PaymentGatewayTableFilterComposer, $$PaymentGatewayTableOrderingComposer, $$PaymentGatewayTableAnnotationComposer, $$PaymentGatewayTableCreateCompanionBuilder, $$PaymentGatewayTableUpdateCompanionBuilder, (PaymentGatewayData, BaseReferences<_$SharedDatabase, $PaymentGatewayTable, PaymentGatewayData>), PaymentGatewayData, PrefetchHooks Function()>
$$PaymentGatewayTableUpdateCompanionBuilder = PaymentGatewayCompanion Function({Value<bool> active, Value<String> id, Value<String> name, Value<int> rowid})
$$ProductTableCreateCompanionBuilder = ProductCompanion Function({required bool active, required int categoryId, Value<String?> description, required double estimatedInputPrice, Value<int> id, Value<String?> imagePath, required String name, required double price, required double taxRate})
$$ProductTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $ProductTable, ProductData, $$ProductTableFilterComposer, $$ProductTableOrderingComposer, $$ProductTableAnnotationComposer, $$ProductTableCreateCompanionBuilder, $$ProductTableUpdateCompanionBuilder, (ProductData, $$ProductTableReferences), ProductData, PrefetchHooks Function({bool categoryId, bool salesOrderLineRefs})>
$$ProductTableUpdateCompanionBuilder = ProductCompanion Function({Value<bool> active, Value<int> categoryId, Value<String?> description, Value<double> estimatedInputPrice, Value<int> id, Value<String?> imagePath, Value<String> name, Value<double> price, Value<double> taxRate})
$$ProjectTableCreateCompanionBuilder = ProjectCompanion Function({required String code, Value<String?> description, Value<int> id, required String name, Value<String?> note})
$$ProjectTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $ProjectTable, ProjectData, $$ProjectTableFilterComposer, $$ProjectTableOrderingComposer, $$ProjectTableAnnotationComposer, $$ProjectTableCreateCompanionBuilder, $$ProjectTableUpdateCompanionBuilder, (ProjectData, $$ProjectTableReferences), ProjectData, PrefetchHooks Function({bool contributorRefs})>
$$ProjectTableUpdateCompanionBuilder = ProjectCompanion Function({Value<String> code, Value<String?> description, Value<int> id, Value<String> name, Value<String?> note})
$$SalesOrderLineTableCreateCompanionBuilder = SalesOrderLineCompanion Function({required double amount, Value<int> id, required int productId, required int salesOrderId, required double taxAmount, required double units})
$$SalesOrderLineTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $SalesOrderLineTable, SalesOrderLineData, $$SalesOrderLineTableFilterComposer, $$SalesOrderLineTableOrderingComposer, $$SalesOrderLineTableAnnotationComposer, $$SalesOrderLineTableCreateCompanionBuilder, $$SalesOrderLineTableUpdateCompanionBuilder, (SalesOrderLineData, $$SalesOrderLineTableReferences), SalesOrderLineData, PrefetchHooks Function({bool productId, bool salesOrderId})>
$$SalesOrderLineTableUpdateCompanionBuilder = SalesOrderLineCompanion Function({Value<double> amount, Value<int> id, Value<int> productId, Value<int> salesOrderId, Value<double> taxAmount, Value<double> units})
$$SalesOrderTableCreateCompanionBuilder = SalesOrderCompanion Function({required double amount, required int customerId, Value<int> id, required DateTime orderDateTime, required int sellerId, required String status, required double taxAmount})
$$SalesOrderTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $SalesOrderTable, SalesOrderData, $$SalesOrderTableFilterComposer, $$SalesOrderTableOrderingComposer, $$SalesOrderTableAnnotationComposer, $$SalesOrderTableCreateCompanionBuilder, $$SalesOrderTableUpdateCompanionBuilder, (SalesOrderData, $$SalesOrderTableReferences), SalesOrderData, PrefetchHooks Function({bool customerId, bool salesOrderLineRefs, bool sellerId})>
$$SalesOrderTableUpdateCompanionBuilder = SalesOrderCompanion Function({Value<double> amount, Value<int> customerId, Value<int> id, Value<DateTime> orderDateTime, Value<int> sellerId, Value<String> status, Value<double> taxAmount})
$$SongTableCreateCompanionBuilder = SongCompanion Function({required int albumId, Value<String?> description, Value<int> id, Value<String?> imagePath, required bool locked, required String name, Value<String?> note, required bool published, Value<String?> youtubeCode, Value<String?> youtubeVideoInfo})
$$SongTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $SongTable, SongData, $$SongTableFilterComposer, $$SongTableOrderingComposer, $$SongTableAnnotationComposer, $$SongTableCreateCompanionBuilder, $$SongTableUpdateCompanionBuilder, (SongData, $$SongTableReferences), SongData, PrefetchHooks Function({bool albumId})>
$$SongTableUpdateCompanionBuilder = SongCompanion Function({Value<int> albumId, Value<String?> description, Value<int> id, Value<String?> imagePath, Value<bool> locked, Value<String> name, Value<String?> note, Value<bool> published, Value<String?> youtubeCode, Value<String?> youtubeVideoInfo})
$$SupplierTableCreateCompanionBuilder = SupplierCompanion Function({required bool active, Value<String?> address, Value<String?> description, required String email, Value<int> id, Value<String?> imagePath, required String name, Value<String?> phone, required int supplierTypeId})
$$SupplierTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $SupplierTable, SupplierData, $$SupplierTableFilterComposer, $$SupplierTableOrderingComposer, $$SupplierTableAnnotationComposer, $$SupplierTableCreateCompanionBuilder, $$SupplierTableUpdateCompanionBuilder, (SupplierData, $$SupplierTableReferences), SupplierData, PrefetchHooks Function({bool supplierTypeId})>
$$SupplierTableUpdateCompanionBuilder = SupplierCompanion Function({Value<bool> active, Value<String?> address, Value<String?> description, Value<String> email, Value<int> id, Value<String?> imagePath, Value<String> name, Value<String?> phone, Value<int> supplierTypeId})
$$SupplierTypeTableCreateCompanionBuilder = SupplierTypeCompanion Function({required String code, Value<int> id, required String name})
$$SupplierTypeTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $SupplierTypeTable, SupplierTypeData, $$SupplierTypeTableFilterComposer, $$SupplierTypeTableOrderingComposer, $$SupplierTypeTableAnnotationComposer, $$SupplierTypeTableCreateCompanionBuilder, $$SupplierTypeTableUpdateCompanionBuilder, (SupplierTypeData, $$SupplierTypeTableReferences), SupplierTypeData, PrefetchHooks Function({bool supplierRefs})>
$$SupplierTypeTableUpdateCompanionBuilder = SupplierTypeCompanion Function({Value<String> code, Value<int> id, Value<String> name})
$$SystemLogTableCreateCompanionBuilder = SystemLogCompanion Function({required String content, required DateTime createDateTime, Value<int> id, required String severity})
$$SystemLogTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $SystemLogTable, SystemLogData, $$SystemLogTableFilterComposer, $$SystemLogTableOrderingComposer, $$SystemLogTableAnnotationComposer, $$SystemLogTableCreateCompanionBuilder, $$SystemLogTableUpdateCompanionBuilder, (SystemLogData, BaseReferences<_$SharedDatabase, $SystemLogTable, SystemLogData>), SystemLogData, PrefetchHooks Function()>
$$SystemLogTableUpdateCompanionBuilder = SystemLogCompanion Function({Value<String> content, Value<DateTime> createDateTime, Value<int> id, Value<String> severity})
$$TeacherPositionTableCreateCompanionBuilder = TeacherPositionCompanion Function({required String id, required String name, Value<int> rowid})
$$TeacherPositionTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $TeacherPositionTable, TeacherPositionData, $$TeacherPositionTableFilterComposer, $$TeacherPositionTableOrderingComposer, $$TeacherPositionTableAnnotationComposer, $$TeacherPositionTableCreateCompanionBuilder, $$TeacherPositionTableUpdateCompanionBuilder, (TeacherPositionData, $$TeacherPositionTableReferences), TeacherPositionData, PrefetchHooks Function({bool teacherRefs})>
$$TeacherPositionTableUpdateCompanionBuilder = TeacherPositionCompanion Function({Value<String> id, Value<String> name, Value<int> rowid})
$$TeacherTableCreateCompanionBuilder = TeacherCompanion Function({required bool active, required DateTime birthday, Value<String?> countryId, Value<String?> description, required String email, Value<String?> facebook, required String fullName, required String genderId, Value<int> id, Value<String?> imagePath, required bool locked, Value<String?> note, Value<String?> phoneNumber, Value<String?> skype, required String teacherPositionId, required int universityId, Value<String?> youtubeVideoCode})
$$TeacherTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $TeacherTable, TeacherData, $$TeacherTableFilterComposer, $$TeacherTableOrderingComposer, $$TeacherTableAnnotationComposer, $$TeacherTableCreateCompanionBuilder, $$TeacherTableUpdateCompanionBuilder, (TeacherData, $$TeacherTableReferences), TeacherData, PrefetchHooks Function({bool countryId, bool genderId, bool teacherPositionId, bool universityId})>
$$TeacherTableUpdateCompanionBuilder = TeacherCompanion Function({Value<bool> active, Value<DateTime> birthday, Value<String?> countryId, Value<String?> description, Value<String> email, Value<String?> facebook, Value<String> fullName, Value<String> genderId, Value<int> id, Value<String?> imagePath, Value<bool> locked, Value<String?> note, Value<String?> phoneNumber, Value<String?> skype, Value<String> teacherPositionId, Value<int> universityId, Value<String?> youtubeVideoCode})
$$UniversityTableCreateCompanionBuilder = UniversityCompanion Function({required bool active, required String code, Value<String?> description, Value<int> id, Value<String?> imagePath, required bool locked, required String name, required String nameInEnglish, Value<String?> note})
$$UniversityTableProcessedTableManager = ProcessedTableManager<_$SharedDatabase, $UniversityTable, UniversityData, $$UniversityTableFilterComposer, $$UniversityTableOrderingComposer, $$UniversityTableAnnotationComposer, $$UniversityTableCreateCompanionBuilder, $$UniversityTableUpdateCompanionBuilder, (UniversityData, $$UniversityTableReferences), UniversityData, PrefetchHooks Function({bool teacherRefs})>
$$UniversityTableUpdateCompanionBuilder = UniversityCompanion Function({Value<bool> active, Value<String> code, Value<String?> description, Value<int> id, Value<String?> imagePath, Value<bool> locked, Value<String> name, Value<String> nameInEnglish, Value<String?> note})