$$BookTableReferences class final
Constructors
-
$$BookTableReferences(_$SharedDatabase $_db, TableInfo<
$BookTable, BookData> $_table, TypedResult $_typedResult)
Properties
- $_db → _$SharedDatabase
-
The database instance
finalinherited
- $_item → BookData
-
The item these references are for.
latefinalinherited
-
$_table
→ TableInfo<
$BookTable, BookData> -
The table of this item
finalinherited
- $_typedResult → TypedResult
-
The raw
TypedResultfor this itemfinalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- lessonRefs → $$LessonTableProcessedTableManager
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$_itemColumn<
C extends Object> (String name) → C? -
Extracts the value of a column with the given
namein the$_typedResultrow.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited