$$SalesOrderLineTableReferences class final

Constructors

$$SalesOrderLineTableReferences(_$SharedDatabase $_db, TableInfo<$SalesOrderLineTable, SalesOrderLineData> $_table, TypedResult $_typedResult)

Properties

$_db → _$SharedDatabase
The database instance
finalinherited
$_item SalesOrderLineData
The item these references are for.
latefinalinherited
$_table → TableInfo<$SalesOrderLineTable, SalesOrderLineData>
The table of this item
finalinherited
$_typedResult → TypedResult
The raw TypedResult for this item
finalinherited
hashCode int
The hash code for this object.
no setterinherited
productId $$ProductTableProcessedTableManager
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesOrderId $$SalesOrderTableProcessedTableManager
no setter

Methods

$_itemColumn<C extends Object>(String name) → C?
Extracts the value of a column with the given name in the $_typedResult row.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited