$$TeacherTableReferences class final

Constructors

$$TeacherTableReferences(_$SharedDatabase $_db, TableInfo<$TeacherTable, TeacherData> $_table, TypedResult $_typedResult)

Properties

$_db → _$SharedDatabase
The database instance
finalinherited
$_item TeacherData
The item these references are for.
latefinalinherited
$_table → TableInfo<$TeacherTable, TeacherData>
The table of this item
finalinherited
$_typedResult → TypedResult
The raw TypedResult for this item
finalinherited
countryId $$CountryTableProcessedTableManager?
no setter
genderId $$GenderTableProcessedTableManager
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
teacherPositionId $$TeacherPositionTableProcessedTableManager
no setter
universityId $$UniversityTableProcessedTableManager
no setter

Methods

$_itemColumn<C extends Object>(String name) → C?
Extracts the value of a column with the given name in the $_typedResult row.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited