createAlias method

  1. @override
$BookTable createAlias(
  1. String alias
)

Creates an alias of this table or view that will write the name alias when used in a query.

Implementation

@override
$BookTable createAlias(String alias) {
  return $BookTable(attachedDatabase, alias);
}