createAlias method

  1. @override
$EmployeePositionTable createAlias(
  1. String alias
)

Creates an alias of this table or view that will write the name alias when used in a query.

Implementation

@override
$EmployeePositionTable createAlias(String alias) {
  return $EmployeePositionTable(attachedDatabase, alias);
}