AlbumData class

Constructors

AlbumData({required int id, required String code, required String name, required String nameInEnglish, required int seqNum, required bool published, required bool locked, String? imagePath, required int publishedSongCount, required int totalSongCount, String? description, String? note})
const
AlbumData.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

code String
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
imagePath String?
final
locked bool
final
name String
final
nameInEnglish String
final
note String?
final
published bool
final
publishedSongCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seqNum int
final
totalSongCount int
final

Methods

copyWith({int? id, String? code, String? name, String? nameInEnglish, int? seqNum, bool? published, bool? locked, Value<String?> imagePath = const Value.absent(), int? publishedSongCount, int? totalSongCount, Value<String?> description = const Value.absent(), Value<String?> note = const Value.absent()}) AlbumData
copyWithCompanion(AlbumCompanion data) AlbumData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) AlbumCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override