AppUserCompanion class

Constructors

AppUserCompanion({Value<int> id = const Value.absent(), Value<String> userName = const Value.absent(), Value<String> email = const Value.absent(), Value<String> fullName = const Value.absent(), Value<String> encryptedPassword = const Value.absent(), Value<bool> enabled = const Value.absent(), Value<bool> activated = const Value.absent(), Value<String?> accessToken = const Value.absent(), Value<int?> employeeId = const Value.absent(), Value<DateTime?> lastActiveDatetime = const Value.absent(), Value<bool> isSystemUser = const Value.absent(), Value<String?> imagePath = const Value.absent()})
const
AppUserCompanion.insert({Value<int> id = const Value.absent(), required String userName, required String email, required String fullName, required String encryptedPassword, required bool enabled, required bool activated, Value<String?> accessToken = const Value.absent(), Value<int?> employeeId = const Value.absent(), Value<DateTime?> lastActiveDatetime = const Value.absent(), required bool isSystemUser, Value<String?> imagePath = const Value.absent()})

Properties

accessToken → Value<String?>
final
activated → Value<bool>
final
email → Value<String>
final
employeeId → Value<int?>
final
enabled → Value<bool>
final
encryptedPassword → Value<String>
final
fullName → Value<String>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
imagePath → Value<String?>
final
isSystemUser → Value<bool>
final
lastActiveDatetime → Value<DateTime?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userName → Value<String>
final

Methods

copyWith({Value<int>? id, Value<String>? userName, Value<String>? email, Value<String>? fullName, Value<String>? encryptedPassword, Value<bool>? enabled, Value<bool>? activated, Value<String?>? accessToken, Value<int?>? employeeId, Value<DateTime?>? lastActiveDatetime, Value<bool>? isSystemUser, Value<String?>? imagePath}) AppUserCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<String>? userName, Expression<String>? email, Expression<String>? fullName, Expression<String>? encryptedPassword, Expression<bool>? enabled, Expression<bool>? activated, Expression<String>? accessToken, Expression<int>? employeeId, Expression<DateTime>? lastActiveDatetime, Expression<bool>? isSystemUser, Expression<String>? imagePath}) → Insertable<AppUserData>