AppUserData class

Constructors

AppUserData({required int id, required String userName, required String email, required String fullName, required String encryptedPassword, required bool enabled, required bool activated, String? accessToken, int? employeeId, DateTime? lastActiveDatetime, required bool isSystemUser, String? imagePath})
const
AppUserData.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

accessToken String?
final
activated bool
final
email String
final
employeeId int?
final
enabled bool
final
encryptedPassword String
final
fullName String
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
imagePath String?
final
isSystemUser bool
final
lastActiveDatetime DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userName String
final

Methods

copyWith({int? id, String? userName, String? email, String? fullName, String? encryptedPassword, bool? enabled, bool? activated, Value<String?> accessToken = const Value.absent(), Value<int?> employeeId = const Value.absent(), Value<DateTime?> lastActiveDatetime = const Value.absent(), bool? isSystemUser, Value<String?> imagePath = const Value.absent()}) AppUserData
copyWithCompanion(AppUserCompanion data) AppUserData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) AppUserCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override