BookCompanion class

Constructors

BookCompanion({Value<int> id = const Value.absent(), Value<String> code = const Value.absent(), Value<String> title = const Value.absent(), Value<int> seqNum = const Value.absent(), Value<bool> published = const Value.absent(), Value<bool> locked = const Value.absent(), Value<String?> imagePath = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> note = const Value.absent()})
const
BookCompanion.insert({Value<int> id = const Value.absent(), required String code, required String title, required int seqNum, required bool published, required bool locked, Value<String?> imagePath = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> note = const Value.absent()})

Properties

code → Value<String>
final
description → Value<String?>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
imagePath → Value<String?>
final
locked → Value<bool>
final
note → Value<String?>
final
published → Value<bool>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seqNum → Value<int>
final
title → Value<String>
final

Methods

copyWith({Value<int>? id, Value<String>? code, Value<String>? title, Value<int>? seqNum, Value<bool>? published, Value<bool>? locked, Value<String?>? imagePath, Value<String?>? description, Value<String?>? note}) BookCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<String>? code, Expression<String>? title, Expression<int>? seqNum, Expression<bool>? published, Expression<bool>? locked, Expression<String>? imagePath, Expression<String>? description, Expression<String>? note}) → Insertable<BookData>