CategoryData class

Constructors

CategoryData({required int id, required String code, required String name, String? imagePath, String? description})
const
CategoryData.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

code String
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
imagePath String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, String? code, String? name, Value<String?> imagePath = const Value.absent(), Value<String?> description = const Value.absent()}) CategoryData
copyWithCompanion(CategoryCompanion data) CategoryData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) CategoryCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override