ContributorCompanion class

Constructors

ContributorCompanion({Value<int> id = const Value.absent(), Value<int> projectId = const Value.absent(), Value<int> appUserId = const Value.absent()})
const
ContributorCompanion.insert({Value<int> id = const Value.absent(), required int projectId, required int appUserId})

Properties

appUserId → Value<int>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
projectId → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Value<int>? id, Value<int>? projectId, Value<int>? appUserId}) ContributorCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<int>? projectId, Expression<int>? appUserId}) → Insertable<ContributorData>