ContributorData class

Constructors

ContributorData({required int id, required int projectId, required int appUserId})
const
ContributorData.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

appUserId int
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
projectId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, int? projectId, int? appUserId}) ContributorData
copyWithCompanion(ContributorCompanion data) ContributorData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) ContributorCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override