CountryCompanion class

Constructors

CountryCompanion({Value<String> id = const Value.absent(), Value<String> code = const Value.absent(), Value<String> name = const Value.absent(), Value<String> nameInEnglish = const Value.absent(), Value<String> countryCode = const Value.absent(), Value<String> isoCode2 = const Value.absent(), Value<String> isoCode3 = const Value.absent(), Value<int> population = const Value.absent(), Value<int> area = const Value.absent(), Value<double?> gdp = const Value.absent(), Value<String?> description = const Value.absent(), Value<int> rowid = const Value.absent()})
const
CountryCompanion.insert({required String id, required String code, required String name, required String nameInEnglish, required String countryCode, required String isoCode2, required String isoCode3, required int population, required int area, Value<double?> gdp = const Value.absent(), Value<String?> description = const Value.absent(), Value<int> rowid = const Value.absent()})

Properties

area → Value<int>
final
code → Value<String>
final
countryCode → Value<String>
final
description → Value<String?>
final
gdp → Value<double?>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<String>
final
isoCode2 → Value<String>
final
isoCode3 → Value<String>
final
name → Value<String>
final
nameInEnglish → Value<String>
final
population → Value<int>
final
rowid → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Value<String>? id, Value<String>? code, Value<String>? name, Value<String>? nameInEnglish, Value<String>? countryCode, Value<String>? isoCode2, Value<String>? isoCode3, Value<int>? population, Value<int>? area, Value<double?>? gdp, Value<String?>? description, Value<int>? rowid}) CountryCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<String>? id, Expression<String>? code, Expression<String>? name, Expression<String>? nameInEnglish, Expression<String>? countryCode, Expression<String>? isoCode2, Expression<String>? isoCode3, Expression<int>? population, Expression<int>? area, Expression<double>? gdp, Expression<String>? description, Expression<int>? rowid}) → Insertable<CountryData>