CountryData class

Constructors

CountryData({required String id, required String code, required String name, required String nameInEnglish, required String countryCode, required String isoCode2, required String isoCode3, required int population, required int area, double? gdp, String? description})
const
CountryData.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

area int
final
code String
final
countryCode String
final
description String?
final
gdp double?
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
isoCode2 String
final
isoCode3 String
final
name String
final
nameInEnglish String
final
population int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, String? code, String? name, String? nameInEnglish, String? countryCode, String? isoCode2, String? isoCode3, int? population, int? area, Value<double?> gdp = const Value.absent(), Value<String?> description = const Value.absent()}) CountryData
copyWithCompanion(CountryCompanion data) CountryData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) CountryCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override