CouponCompanion class

Constructors

CouponCompanion({Value<int> id = const Value.absent(), Value<String> code = const Value.absent(), Value<String> name = const Value.absent(), Value<bool> active = const Value.absent(), Value<String> type = const Value.absent(), Value<String?> description = const Value.absent()})
const
CouponCompanion.insert({Value<int> id = const Value.absent(), required String code, required String name, required bool active, required String type, Value<String?> description = const Value.absent()})

Properties

active → Value<bool>
final
code → Value<String>
final
description → Value<String?>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
name → Value<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type → Value<String>
final

Methods

copyWith({Value<int>? id, Value<String>? code, Value<String>? name, Value<bool>? active, Value<String>? type, Value<String?>? description}) CouponCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<String>? code, Expression<String>? name, Expression<bool>? active, Expression<String>? type, Expression<String>? description}) → Insertable<CouponData>