CurrencyCompanion class
Constructors
-
CurrencyCompanion({Value<
String> id = const Value.absent(), Value<String> symbol = const Value.absent(), Value<String> name = const Value.absent(), Value<String?> description = const Value.absent(), Value<int> rowid = const Value.absent()}) -
const
-
CurrencyCompanion.insert({required String id, required String symbol, required String name, Value<
String?> description = const Value.absent(), Value<int> rowid = const Value.absent()})
Properties
Methods
-
copyWith(
{Value< String> ? id, Value<String> ? symbol, Value<String> ? name, Value<String?> ? description, Value<int> ? rowid}) → CurrencyCompanion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited