EmployeeData class

Constructors

EmployeeData({required int id, required String empNumber, required String name, required String email, required int employeePositionId, required int departmentId, required DateTime birthday, required DateTime hireDate, String? imagePath, String? address})
const
EmployeeData.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

address String?
final
birthday DateTime
final
departmentId int
final
email String
final
employeePositionId int
final
empNumber String
final
hashCode int
The hash code for this object.
no setteroverride
hireDate DateTime
final
id int
final
imagePath String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, String? empNumber, String? name, String? email, int? employeePositionId, int? departmentId, DateTime? birthday, DateTime? hireDate, Value<String?> imagePath = const Value.absent(), Value<String?> address = const Value.absent()}) EmployeeData
copyWithCompanion(EmployeeCompanion data) EmployeeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) EmployeeCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override