EmployeePositionCompanion class
Constructors
-
EmployeePositionCompanion({Value<
int> id = const Value.absent(), Value<String> code = const Value.absent(), Value<String> name = const Value.absent()}) -
const
-
EmployeePositionCompanion.insert({Value<
int> id = const Value.absent(), required String code, required String name})
Properties
Methods
-
copyWith(
{Value< int> ? id, Value<String> ? code, Value<String> ? name}) → EmployeePositionCompanion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
custom(
{Expression< int> ? id, Expression<String> ? code, Expression<String> ? name}) → Insertable<EmployeePositionData>