EmploymentHistoryCompanion class

Constructors

EmploymentHistoryCompanion({Value<int> id = const Value.absent(), Value<int> employeeId = const Value.absent(), Value<int> employeePositionId = const Value.absent(), Value<int> departmentId = const Value.absent(), Value<int> companyId = const Value.absent(), Value<DateTime> fromDate = const Value.absent(), Value<DateTime> toDate = const Value.absent()})
const
EmploymentHistoryCompanion.insert({Value<int> id = const Value.absent(), required int employeeId, required int employeePositionId, required int departmentId, required int companyId, required DateTime fromDate, required DateTime toDate})

Properties

companyId → Value<int>
final
departmentId → Value<int>
final
employeeId → Value<int>
final
employeePositionId → Value<int>
final
fromDate → Value<DateTime>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate → Value<DateTime>
final

Methods

copyWith({Value<int>? id, Value<int>? employeeId, Value<int>? employeePositionId, Value<int>? departmentId, Value<int>? companyId, Value<DateTime>? fromDate, Value<DateTime>? toDate}) EmploymentHistoryCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<int>? employeeId, Expression<int>? employeePositionId, Expression<int>? departmentId, Expression<int>? companyId, Expression<DateTime>? fromDate, Expression<DateTime>? toDate}) → Insertable<EmploymentHistoryData>