FootballPlayerCompanion class

Constructors

FootballPlayerCompanion({Value<int> id = const Value.absent(), Value<String> fullName = const Value.absent(), Value<DateTime> birthday = const Value.absent(), Value<String> countryId = const Value.absent(), Value<String?> imagePath = const Value.absent(), Value<String?> description = const Value.absent()})
const
FootballPlayerCompanion.insert({Value<int> id = const Value.absent(), required String fullName, required DateTime birthday, required String countryId, Value<String?> imagePath = const Value.absent(), Value<String?> description = const Value.absent()})

Properties

birthday → Value<DateTime>
final
countryId → Value<String>
final
description → Value<String?>
final
fullName → Value<String>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
imagePath → Value<String?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Value<int>? id, Value<String>? fullName, Value<DateTime>? birthday, Value<String>? countryId, Value<String?>? imagePath, Value<String?>? description}) FootballPlayerCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<String>? fullName, Expression<DateTime>? birthday, Expression<String>? countryId, Expression<String>? imagePath, Expression<String>? description}) → Insertable<FootballPlayerData>