LessonData class

Constructors

LessonData({required int id, required String title, required String titleInEnglish, required int seqNum, required bool locked, required bool published, DateTime? publishDate, String? imagePath, required int bookId, String? description, String? note})
const
LessonData.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

bookId int
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
imagePath String?
final
locked bool
final
note String?
final
publishDate DateTime?
final
published bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seqNum int
final
title String
final
titleInEnglish String
final

Methods

copyWith({int? id, String? title, String? titleInEnglish, int? seqNum, bool? locked, bool? published, Value<DateTime?> publishDate = const Value.absent(), Value<String?> imagePath = const Value.absent(), int? bookId, Value<String?> description = const Value.absent(), Value<String?> note = const Value.absent()}) LessonData
copyWithCompanion(LessonCompanion data) LessonData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) LessonCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override