NotificationMessageCompanion class

Constructors

NotificationMessageCompanion({Value<int> id = const Value.absent(), Value<String> title = const Value.absent(), Value<String> message = const Value.absent(), Value<DateTime> createDateTime = const Value.absent(), Value<bool> read = const Value.absent(), Value<String> type = const Value.absent()})
const
NotificationMessageCompanion.insert({Value<int> id = const Value.absent(), required String title, required String message, required DateTime createDateTime, required bool read, required String type})

Properties

createDateTime → Value<DateTime>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
message → Value<String>
final
read → Value<bool>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title → Value<String>
final
type → Value<String>
final

Methods

copyWith({Value<int>? id, Value<String>? title, Value<String>? message, Value<DateTime>? createDateTime, Value<bool>? read, Value<String>? type}) NotificationMessageCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<String>? title, Expression<String>? message, Expression<DateTime>? createDateTime, Expression<bool>? read, Expression<String>? type}) → Insertable<NotificationMessageData>