NotificationMessageData class

Constructors

NotificationMessageData({required int id, required String title, required String message, required DateTime createDateTime, required bool read, required String type})
const
NotificationMessageData.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

createDateTime DateTime
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
message String
final
read bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
type String
final

Methods

copyWith({int? id, String? title, String? message, DateTime? createDateTime, bool? read, String? type}) NotificationMessageData
copyWithCompanion(NotificationMessageCompanion data) NotificationMessageData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) NotificationMessageCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override