PaymentGatewayData class
Constructors
- PaymentGatewayData({required String id, required String name, required bool active})
-
const
-
PaymentGatewayData.fromJson(Map<
String, dynamic> json, {ValueSerializer? serializer}) -
factory
Properties
Methods
-
copyWith(
{String? id, String? name, bool? active}) → PaymentGatewayData -
copyWithCompanion(
PaymentGatewayCompanion data) → PaymentGatewayData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toCompanion(
bool nullToAbsent) → PaymentGatewayCompanion -
toJson(
{ValueSerializer? serializer}) → Map< String, dynamic> -
Converts this object into a representation that can be encoded with
json. Theserializercan be used to configure how individual values will be encoded. By default,DriftRuntimeOptions.defaultSerializerwill be used. SeeValueSerializer.defaultsfor details. -
toJsonString(
{ValueSerializer? serializer}) → String -
Converts this object into a json representation. The
serializercan be used to configure how individual values will be encoded. By default,DriftRuntimeOptions.defaultSerializerwill be used. SeeValueSerializer.defaultsfor details.inherited -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override