ProductCompanion class

Constructors

ProductCompanion({Value<int> id = const Value.absent(), Value<String> name = const Value.absent(), Value<double> price = const Value.absent(), Value<bool> active = const Value.absent(), Value<String?> imagePath = const Value.absent(), Value<int> categoryId = const Value.absent(), Value<double> estimatedInputPrice = const Value.absent(), Value<double> taxRate = const Value.absent(), Value<String?> description = const Value.absent()})
const
ProductCompanion.insert({Value<int> id = const Value.absent(), required String name, required double price, required bool active, Value<String?> imagePath = const Value.absent(), required int categoryId, required double estimatedInputPrice, required double taxRate, Value<String?> description = const Value.absent()})

Properties

active → Value<bool>
final
categoryId → Value<int>
final
description → Value<String?>
final
estimatedInputPrice → Value<double>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
imagePath → Value<String?>
final
name → Value<String>
final
price → Value<double>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taxRate → Value<double>
final

Methods

copyWith({Value<int>? id, Value<String>? name, Value<double>? price, Value<bool>? active, Value<String?>? imagePath, Value<int>? categoryId, Value<double>? estimatedInputPrice, Value<double>? taxRate, Value<String?>? description}) ProductCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<String>? name, Expression<double>? price, Expression<bool>? active, Expression<String>? imagePath, Expression<int>? categoryId, Expression<double>? estimatedInputPrice, Expression<double>? taxRate, Expression<String>? description}) → Insertable<ProductData>