SalesOrderCompanion class

Constructors

SalesOrderCompanion({Value<int> id = const Value.absent(), Value<DateTime> orderDateTime = const Value.absent(), Value<double> amount = const Value.absent(), Value<double> taxAmount = const Value.absent(), Value<String> status = const Value.absent(), Value<int> sellerId = const Value.absent(), Value<int> customerId = const Value.absent()})
const
SalesOrderCompanion.insert({Value<int> id = const Value.absent(), required DateTime orderDateTime, required double amount, required double taxAmount, required String status, required int sellerId, required int customerId})

Properties

amount → Value<double>
final
customerId → Value<int>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
orderDateTime → Value<DateTime>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sellerId → Value<int>
final
status → Value<String>
final
taxAmount → Value<double>
final

Methods

copyWith({Value<int>? id, Value<DateTime>? orderDateTime, Value<double>? amount, Value<double>? taxAmount, Value<String>? status, Value<int>? sellerId, Value<int>? customerId}) SalesOrderCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<DateTime>? orderDateTime, Expression<double>? amount, Expression<double>? taxAmount, Expression<String>? status, Expression<int>? sellerId, Expression<int>? customerId}) → Insertable<SalesOrderData>