SalesOrderData class

Constructors

SalesOrderData({required int id, required DateTime orderDateTime, required double amount, required double taxAmount, required String status, required int sellerId, required int customerId})
const
SalesOrderData.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

amount double
final
customerId int
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
orderDateTime DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sellerId int
final
status String
final
taxAmount double
final

Methods

copyWith({int? id, DateTime? orderDateTime, double? amount, double? taxAmount, String? status, int? sellerId, int? customerId}) SalesOrderData
copyWithCompanion(SalesOrderCompanion data) SalesOrderData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) SalesOrderCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override