SongData class

Constructors

SongData({required int id, required String name, required bool locked, required bool published, String? imagePath, String? description, String? note, String? youtubeCode, String? youtubeVideoInfo, required int albumId})
const
SongData.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

albumId int
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
imagePath String?
final
locked bool
final
name String
final
note String?
final
published bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
youtubeCode String?
final
youtubeVideoInfo String?
final

Methods

copyWith({int? id, String? name, bool? locked, bool? published, Value<String?> imagePath = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> note = const Value.absent(), Value<String?> youtubeCode = const Value.absent(), Value<String?> youtubeVideoInfo = const Value.absent(), int? albumId}) SongData
copyWithCompanion(SongCompanion data) SongData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) SongCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override