SupplierData class

Constructors

SupplierData({required int id, required String name, required bool active, required String email, String? address, String? phone, String? description, required int supplierTypeId, String? imagePath})
const
SupplierData.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

active bool
final
address String?
final
description String?
final
email String
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
imagePath String?
final
name String
final
phone String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supplierTypeId int
final

Methods

copyWith({int? id, String? name, bool? active, String? email, Value<String?> address = const Value.absent(), Value<String?> phone = const Value.absent(), Value<String?> description = const Value.absent(), int? supplierTypeId, Value<String?> imagePath = const Value.absent()}) SupplierData
copyWithCompanion(SupplierCompanion data) SupplierData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) SupplierCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override