SystemLogCompanion class
Constructors
-
SystemLogCompanion({Value<
int> id = const Value.absent(), Value<DateTime> createDateTime = const Value.absent(), Value<String> severity = const Value.absent(), Value<String> content = const Value.absent()}) -
const
-
SystemLogCompanion.insert({Value<
int> id = const Value.absent(), required DateTime createDateTime, required String severity, required String content})
Properties
Methods
-
copyWith(
{Value< int> ? id, Value<DateTime> ? createDateTime, Value<String> ? severity, Value<String> ? content}) → SystemLogCompanion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited