TeacherData class
Constructors
TeacherData ({required int id , required String fullName , required DateTime birthday , required String genderId , required String teacherPositionId , required bool locked , required bool active , required int universityId , String ? countryId , String ? youtubeVideoCode , required String email , String ? skype , String ? facebook , String ? phoneNumber , String ? description , String ? note , String ? imagePath })
const
TeacherData.fromJson (Map <String , dynamic > json , {ValueSerializer? serializer })
factory
Methods
copyWith ({int ? id , String ? fullName , DateTime ? birthday , String ? genderId , String ? teacherPositionId , bool ? locked , bool ? active , int ? universityId , Value<String ? > countryId = const Value.absent() , Value<String ? > youtubeVideoCode = const Value.absent() , String ? email , Value<String ? > skype = const Value.absent() , Value<String ? > facebook = const Value.absent() , Value<String ? > phoneNumber = const Value.absent() , Value<String ? > description = const Value.absent() , Value<String ? > note = const Value.absent() , Value<String ? > imagePath = const Value.absent() })
→ TeacherData
copyWithCompanion (TeacherCompanion data )
→ TeacherData
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns (bool nullToAbsent )
→ Map <String , Expression<Object > >
Converts this object into a map of column names to expressions to insert
or update.
toCompanion (bool nullToAbsent )
→ TeacherCompanion
toJson ({ValueSerializer? serializer })
→ Map <String , dynamic >
Converts this object into a representation that can be encoded with
json. The serializer can be used to configure how individual values
will be encoded. By default, DriftRuntimeOptions.defaultSerializer will
be used. See ValueSerializer.defaults for details.
toJsonString ({ValueSerializer? serializer })
→ String
Converts this object into a json representation. The serializer can be
used to configure how individual values will be encoded. By default,
DriftRuntimeOptions.defaultSerializer will be used. See
ValueSerializer.defaults for details.
inherited
toString ()
→ String
A string representation of this object.
override
flutter_artist_backend_sandbox 1.0.1