toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return (StringBuffer('TeacherData(')
        ..write('id: $id, ')
        ..write('fullName: $fullName, ')
        ..write('birthday: $birthday, ')
        ..write('genderId: $genderId, ')
        ..write('teacherPositionId: $teacherPositionId, ')
        ..write('locked: $locked, ')
        ..write('active: $active, ')
        ..write('universityId: $universityId, ')
        ..write('countryId: $countryId, ')
        ..write('youtubeVideoCode: $youtubeVideoCode, ')
        ..write('email: $email, ')
        ..write('skype: $skype, ')
        ..write('facebook: $facebook, ')
        ..write('phoneNumber: $phoneNumber, ')
        ..write('description: $description, ')
        ..write('note: $note, ')
        ..write('imagePath: $imagePath')
        ..write(')'))
      .toString();
}