TeacherPositionCompanion class

Constructors

TeacherPositionCompanion({Value<String> id = const Value.absent(), Value<String> name = const Value.absent(), Value<int> rowid = const Value.absent()})
const
TeacherPositionCompanion.insert({required String id, required String name, Value<int> rowid = const Value.absent()})

Properties

hashCode int
The hash code for this object.
no setterinherited
id → Value<String>
final
name → Value<String>
final
rowid → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Value<String>? id, Value<String>? name, Value<int>? rowid}) TeacherPositionCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<String>? id, Expression<String>? name, Expression<int>? rowid}) → Insertable<TeacherPositionData>