AlbumCompanion class
Constructors
-
AlbumCompanion({Value<int> id = const Value.absent(), Value<String> code = const Value.absent(), Value<String> name = const Value.absent(), Value<String> nameInEnglish = const Value.absent(), Value<int> seqNum = const Value.absent(), Value<bool> published = const Value.absent(), Value<bool> locked = const Value.absent(), Value<String?> imagePath = const Value.absent(), Value<int> publishedSongCount = const Value.absent(), Value<int> totalSongCount = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> note = const Value.absent()})
-
const
-
AlbumCompanion.insert({Value<int> id = const Value.absent(), required String code, required String name, required String nameInEnglish, required int seqNum, required bool published, required bool locked, Value<String?> imagePath = const Value.absent(), required int publishedSongCount, required int totalSongCount, Value<String?> description = const Value.absent(), Value<String?> note = const Value.absent()})
-
Methods
-
copyWith({Value<int>? id, Value<String>? code, Value<String>? name, Value<String>? nameInEnglish, Value<int>? seqNum, Value<bool>? published, Value<bool>? locked, Value<String?>? imagePath, Value<int>? publishedSongCount, Value<int>? totalSongCount, Value<String?>? description, Value<String?>? note})
→ AlbumCompanion
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(bool nullToAbsent)
→ Map<String, Expression<Object>>
-
Converts this object into a map of column names to expressions to insert
or update.
-
toString()
→ String
-
A string representation of this object.
override
Static Methods
-
custom({Expression<int>? id, Expression<String>? code, Expression<String>? name, Expression<String>? nameInEnglish, Expression<int>? seqNum, Expression<bool>? published, Expression<bool>? locked, Expression<String>? imagePath, Expression<int>? publishedSongCount, Expression<int>? totalSongCount, Expression<String>? description, Expression<String>? note})
→ Insertable<AlbumData>
-