CompanyCompanion class
Constructors
-
CompanyCompanion({Value<
int> id = const Value.absent(), Value<int?> companyIdParent = const Value.absent(), Value<String> code = const Value.absent(), Value<String> name = const Value.absent(), Value<String?> imagePath = const Value.absent(), Value<String?> description = const Value.absent()}) -
const
-
CompanyCompanion.insert({Value<
int> id = const Value.absent(), Value<int?> companyIdParent = const Value.absent(), required String code, required String name, Value<String?> imagePath = const Value.absent(), Value<String?> description = const Value.absent()})
Properties
-
code
→ Value<
String> -
final
-
companyIdParent
→ Value<
int?> -
final
-
description
→ Value<
String?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ Value<
int> -
final
-
imagePath
→ Value<
String?> -
final
-
name
→ Value<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Value< int> ? id, Value<int?> ? companyIdParent, Value<String> ? code, Value<String> ? name, Value<String?> ? imagePath, Value<String?> ? description}) → CompanyCompanion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited