CustomerCompanion class

Constructors

CustomerCompanion({Value<int> id = const Value.absent(), Value<String> code = const Value.absent(), Value<String> name = const Value.absent(), Value<bool> vip = const Value.absent(), Value<String?> address = const Value.absent(), Value<String?> phone = const Value.absent(), Value<String> email = const Value.absent(), Value<String?> imagePath = const Value.absent()})
const
CustomerCompanion.insert({Value<int> id = const Value.absent(), required String code, required String name, required bool vip, Value<String?> address = const Value.absent(), Value<String?> phone = const Value.absent(), required String email, Value<String?> imagePath = const Value.absent()})

Properties

address → Value<String?>
final
code → Value<String>
final
email → Value<String>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
imagePath → Value<String?>
final
name → Value<String>
final
phone → Value<String?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vip → Value<bool>
final

Methods

copyWith({Value<int>? id, Value<String>? code, Value<String>? name, Value<bool>? vip, Value<String?>? address, Value<String?>? phone, Value<String>? email, Value<String?>? imagePath}) CustomerCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<String>? code, Expression<String>? name, Expression<bool>? vip, Expression<String>? address, Expression<String>? phone, Expression<String>? email, Expression<String>? imagePath}) → Insertable<CustomerData>