EmployeeCompanion class
Constructors
-
EmployeeCompanion({Value<int> id = const Value.absent(), Value<String> empNumber = const Value.absent(), Value<String> name = const Value.absent(), Value<String> email = const Value.absent(), Value<int> employeePositionId = const Value.absent(), Value<int> departmentId = const Value.absent(), Value<DateTime> birthday = const Value.absent(), Value<DateTime> hireDate = const Value.absent(), Value<String?> imagePath = const Value.absent(), Value<String?> address = const Value.absent()})
-
const
-
EmployeeCompanion.insert({Value<int> id = const Value.absent(), required String empNumber, required String name, required String email, required int employeePositionId, required int departmentId, required DateTime birthday, required DateTime hireDate, Value<String?> imagePath = const Value.absent(), Value<String?> address = const Value.absent()})
-
Methods
-
copyWith({Value<int>? id, Value<String>? empNumber, Value<String>? name, Value<String>? email, Value<int>? employeePositionId, Value<int>? departmentId, Value<DateTime>? birthday, Value<DateTime>? hireDate, Value<String?>? imagePath, Value<String?>? address})
→ EmployeeCompanion
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(bool nullToAbsent)
→ Map<String, Expression<Object>>
-
Converts this object into a map of column names to expressions to insert
or update.
-
toString()
→ String
-
A string representation of this object.
override