NoteCompanion class
Constructors
-
NoteCompanion({Value<
int> id = const Value.absent(), Value<String> title = const Value.absent(), Value<String> content = const Value.absent(), Value<DateTime> createDateTime = const Value.absent(), Value<String> colorCode = const Value.absent()}) -
const
-
NoteCompanion.insert({Value<
int> id = const Value.absent(), required String title, required String content, required DateTime createDateTime, required String colorCode})
Properties
-
colorCode
→ Value<
String> -
final
-
content
→ Value<
String> -
final
-
createDateTime
→ Value<
DateTime> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ Value<
int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
title
→ Value<
String> -
final
Methods
-
copyWith(
{Value< int> ? id, Value<String> ? title, Value<String> ? content, Value<DateTime> ? createDateTime, Value<String> ? colorCode}) → NoteCompanion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited