SalesOrderLineCompanion class
Constructors
-
SalesOrderLineCompanion({Value<
int> id = const Value.absent(), Value<int> salesOrderId = const Value.absent(), Value<int> productId = const Value.absent(), Value<double> units = const Value.absent(), Value<double> amount = const Value.absent(), Value<double> taxAmount = const Value.absent()}) -
const
-
SalesOrderLineCompanion.insert({Value<
int> id = const Value.absent(), required int salesOrderId, required int productId, required double units, required double amount, required double taxAmount})
Properties
-
amount
→ Value<
double> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ Value<
int> -
final
-
productId
→ Value<
int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
salesOrderId
→ Value<
int> -
final
-
taxAmount
→ Value<
double> -
final
-
units
→ Value<
double> -
final
Methods
-
copyWith(
{Value< int> ? id, Value<int> ? salesOrderId, Value<int> ? productId, Value<double> ? units, Value<double> ? amount, Value<double> ? taxAmount}) → SalesOrderLineCompanion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited