SalesOrderLineDAOManager class
Constructors
- SalesOrderLineDAOManager(_$SalesOrderLineDAOMixin _db)
Properties
- category → $$CategoryTableTableManager
-
no setter
- company → $$CompanyTableTableManager
-
no setter
- customer → $$CustomerTableTableManager
-
no setter
- department → $$DepartmentTableTableManager
-
no setter
- employee → $$EmployeeTableTableManager
-
no setter
- employeePosition → $$EmployeePositionTableTableManager
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- product → $$ProductTableTableManager
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salesOrder → $$SalesOrderTableTableManager
-
no setter
- salesOrderLine → $$SalesOrderLineTableTableManager
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited