SongCompanion class
Constructors
-
SongCompanion({Value<int> id = const Value.absent(), Value<String> name = const Value.absent(), Value<bool> locked = const Value.absent(), Value<bool> published = const Value.absent(), Value<String?> imagePath = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> note = const Value.absent(), Value<String?> youtubeCode = const Value.absent(), Value<String?> youtubeVideoInfo = const Value.absent(), Value<int> albumId = const Value.absent()})
-
const
-
SongCompanion.insert({Value<int> id = const Value.absent(), required String name, required bool locked, required bool published, Value<String?> imagePath = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> note = const Value.absent(), Value<String?> youtubeCode = const Value.absent(), Value<String?> youtubeVideoInfo = const Value.absent(), required int albumId})
-
Methods
-
copyWith({Value<int>? id, Value<String>? name, Value<bool>? locked, Value<bool>? published, Value<String?>? imagePath, Value<String?>? description, Value<String?>? note, Value<String?>? youtubeCode, Value<String?>? youtubeVideoInfo, Value<int>? albumId})
→ SongCompanion
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(bool nullToAbsent)
→ Map<String, Expression<Object>>
-
Converts this object into a map of column names to expressions to insert
or update.
-
toString()
→ String
-
A string representation of this object.
override
Static Methods
-
custom({Expression<int>? id, Expression<String>? name, Expression<bool>? locked, Expression<bool>? published, Expression<String>? imagePath, Expression<String>? description, Expression<String>? note, Expression<String>? youtubeCode, Expression<String>? youtubeVideoInfo, Expression<int>? albumId})
→ Insertable<SongData>
-