TeacherCompanion class
Constructors
-
TeacherCompanion({Value<int> id = const Value.absent(), Value<String> fullName = const Value.absent(), Value<DateTime> birthday = const Value.absent(), Value<String> genderId = const Value.absent(), Value<String> teacherPositionId = const Value.absent(), Value<bool> locked = const Value.absent(), Value<bool> active = const Value.absent(), Value<int> universityId = const Value.absent(), Value<String?> countryId = const Value.absent(), Value<String?> youtubeVideoCode = const Value.absent(), Value<String> email = const Value.absent(), Value<String?> skype = const Value.absent(), Value<String?> facebook = const Value.absent(), Value<String?> phoneNumber = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> note = const Value.absent(), Value<String?> imagePath = const Value.absent()})
-
const
-
TeacherCompanion.insert({Value<int> id = const Value.absent(), required String fullName, required DateTime birthday, required String genderId, required String teacherPositionId, required bool locked, required bool active, required int universityId, Value<String?> countryId = const Value.absent(), Value<String?> youtubeVideoCode = const Value.absent(), required String email, Value<String?> skype = const Value.absent(), Value<String?> facebook = const Value.absent(), Value<String?> phoneNumber = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> note = const Value.absent(), Value<String?> imagePath = const Value.absent()})
-
Methods
-
copyWith({Value<int>? id, Value<String>? fullName, Value<DateTime>? birthday, Value<String>? genderId, Value<String>? teacherPositionId, Value<bool>? locked, Value<bool>? active, Value<int>? universityId, Value<String?>? countryId, Value<String?>? youtubeVideoCode, Value<String>? email, Value<String?>? skype, Value<String?>? facebook, Value<String?>? phoneNumber, Value<String?>? description, Value<String?>? note, Value<String?>? imagePath})
→ TeacherCompanion
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(bool nullToAbsent)
→ Map<String, Expression<Object>>
-
Converts this object into a map of column names to expressions to insert
or update.
-
toString()
→ String
-
A string representation of this object.
override
Static Methods
-
custom({Expression<int>? id, Expression<String>? fullName, Expression<DateTime>? birthday, Expression<String>? genderId, Expression<String>? teacherPositionId, Expression<bool>? locked, Expression<bool>? active, Expression<int>? universityId, Expression<String>? countryId, Expression<String>? youtubeVideoCode, Expression<String>? email, Expression<String>? skype, Expression<String>? facebook, Expression<String>? phoneNumber, Expression<String>? description, Expression<String>? note, Expression<String>? imagePath})
→ Insertable<TeacherData>
-